@@ -1176,6 +1176,31 @@ class GenTest(unittest.TestCase):
         self.remove('{}2_sub.py'.format(t_))
         self.remove('{}2_out.xml'.format(t_))
 
+    def test_045_attr_prefix(self):
+        "Tests for xlink: and xml: prefixes on attribute names."
+        cmdTempl = (
+            'python3 generateDS.py --no-dates --no-versions '
+            '--enable-slots --disable-generatedssuper-lookup '
+            '--member-specs=dict -f '
+            '-o tests/%s2_sup.py -s tests/%s2_sub.py '
+            '--super=%s2_sup --no-warnings '
+            '--import-path=".." '
+            'tests/%s.xsd'
+        )
+        t_ = 'relative_import'
+        cmd = cmdTempl % (t_, t_, t_, t_, )
+        self.executeClean(cmd)
+        self.compareFiles(
+            '{}1_sup.py'.format(t_),
+            '{}2_sup.py'.format(t_),
+            ('sys.stdout.write',))
+        self.compareFiles('{}1_sub.py'.format(t_), '{}2_sub.py'.format(t_))
+        # Need to preserve generated files for next command, cleanup at end
+        # cleanup generated files
+        #self.remove('{}2_sup.py'.format(t_))
+        #self.remove('{}2_sub.py'.format(t_))
+        #self.remove('{}2_out.xml'.format(t_))
+
     def compareFiles(self, left, right, ignore=None):
         left = os.path.join(TEST_DIR, left)
         right = os.path.join(TEST_DIR, right)
